Crate kcr_submariner_io

Crate kcr_submariner_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the submariner.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

submariner.io/v1alpha1

  • Broker
  • ServiceDiscovery
  • Submariner

Modules

v1alpha1